# - Config to retrieve all components of the gz-sim7 package
#
# This should only be invoked by gz-sim7-config.cmake.
#
# To retrieve this meta-package, use:
# find_package(gz-sim7 COMPONENTS all)
#
# This creates the target gz-sim7::all which will link to all known
# components of gz-sim7, including the core library.
#
# This also creates the variable gz-sim7_ALL_LIBRARIES
#
################################################################################

cmake_minimum_required(VERSION 3.10.2 FATAL_ERROR)

if(gz-sim7_ALL_CONFIG_INCLUDED)
  return()
endif()
set(gz-sim7_ALL_CONFIG_INCLUDED TRUE)

if(NOT gz-sim7-all_FIND_QUIETLY)
  message(STATUS "Looking for all libraries of gz-sim7 -- found version 7.5.0")
endif()


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was gz-all-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/x86_64-linux-gnu/cmake/gz-sim7-all" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Get access to the find_dependency utility
include(CMakeFindDependencyMacro)

# Find the core library
find_dependency(gz-sim7 7.5.0 EXACT)

# Find the component libraries
find_dependency(gz-sim7-rendering 7.5.0 EXACT)
find_dependency(gz-sim7-gui 7.5.0 EXACT)
find_dependency(gz-sim7-ackermann-steering-system 7.5.0 EXACT)
find_dependency(gz-sim7-acoustic-comms-system 7.5.0 EXACT)
find_dependency(gz-sim7-air-pressure-system 7.5.0 EXACT)
find_dependency(gz-sim7-air-speed-system 7.5.0 EXACT)
find_dependency(gz-sim7-altimeter-system 7.5.0 EXACT)
find_dependency(gz-sim7-apply-joint-force-system 7.5.0 EXACT)
find_dependency(gz-sim7-apply-link-wrench-system 7.5.0 EXACT)
find_dependency(gz-sim7-linearbatteryplugin-system 7.5.0 EXACT)
find_dependency(gz-sim7-breadcrumbs-system 7.5.0 EXACT)
find_dependency(gz-sim7-buoyancy-system 7.5.0 EXACT)
find_dependency(gz-sim7-buoyancy-engine-system 7.5.0 EXACT)
find_dependency(gz-sim7-collada-world-exporter-system 7.5.0 EXACT)
find_dependency(gz-sim7-comms-endpoint-system 7.5.0 EXACT)
find_dependency(gz-sim7-contact-system 7.5.0 EXACT)
find_dependency(gz-sim7-camera-video-recorder-system 7.5.0 EXACT)
find_dependency(gz-sim7-detachable-joint-system 7.5.0 EXACT)
find_dependency(gz-sim7-diff-drive-system 7.5.0 EXACT)
find_dependency(gz-sim7-elevator-system 7.5.0 EXACT)
find_dependency(gz-sim7-environment-preload-system 7.5.0 EXACT)
find_dependency(gz-sim7-environmental-sensor-system 7.5.0 EXACT)
find_dependency(gz-sim7-follow-actor-system 7.5.0 EXACT)
find_dependency(gz-sim7-forcetorque-system 7.5.0 EXACT)
find_dependency(gz-sim7-hydrodynamics-system 7.5.0 EXACT)
find_dependency(gz-sim7-imu-system 7.5.0 EXACT)
find_dependency(gz-sim7-joint-controller-system 7.5.0 EXACT)
find_dependency(gz-sim7-joint-position-controller-system 7.5.0 EXACT)
find_dependency(gz-sim7-joint-state-publisher-system 7.5.0 EXACT)
find_dependency(gz-sim7-joint-trajectory-controller-system 7.5.0 EXACT)
find_dependency(gz-sim7-kinetic-energy-monitor-system 7.5.0 EXACT)
find_dependency(gz-sim7-label-system 7.5.0 EXACT)
find_dependency(gz-sim7-lift-drag-system 7.5.0 EXACT)
find_dependency(gz-sim7-log-system 7.5.0 EXACT)
find_dependency(gz-sim7-log-video-recorder-system 7.5.0 EXACT)
find_dependency(gz-sim7-logicalaudiosensorplugin-system 7.5.0 EXACT)
find_dependency(gz-sim7-logical-camera-system 7.5.0 EXACT)
find_dependency(gz-sim7-magnetometer-system 7.5.0 EXACT)
find_dependency(gz-sim7-model-photo-shoot-system 7.5.0 EXACT)
find_dependency(gz-sim7-mecanum-drive-system 7.5.0 EXACT)
find_dependency(gz-sim7-multicopter-motor-model-system 7.5.0 EXACT)
find_dependency(gz-sim7-multicopter-control-system 7.5.0 EXACT)
find_dependency(gz-sim7-navsat-system 7.5.0 EXACT)
find_dependency(gz-sim7-odometry-publisher-system 7.5.0 EXACT)
find_dependency(gz-sim7-opticaltactileplugin-system 7.5.0 EXACT)
find_dependency(gz-sim7-particle-emitter-system 7.5.0 EXACT)
find_dependency(gz-sim7-particle-emitter2-system 7.5.0 EXACT)
find_dependency(gz-sim7-performer-detector-system 7.5.0 EXACT)
find_dependency(gz-sim7-perfect-comms-system 7.5.0 EXACT)
find_dependency(gz-sim7-physics-system 7.5.0 EXACT)
find_dependency(gz-sim7-pose-publisher-system 7.5.0 EXACT)
find_dependency(gz-sim7-rf-comms-system 7.5.0 EXACT)
find_dependency(gz-sim7-scene-broadcaster-system 7.5.0 EXACT)
find_dependency(gz-sim7-sensors-system 7.5.0 EXACT)
find_dependency(gz-sim7-shader-param-system 7.5.0 EXACT)
find_dependency(gz-sim7-thermal-system 7.5.0 EXACT)
find_dependency(gz-sim7-thermal-sensor-system 7.5.0 EXACT)
find_dependency(gz-sim7-thruster-system 7.5.0 EXACT)
find_dependency(gz-sim7-touchplugin-system 7.5.0 EXACT)
find_dependency(gz-sim7-track-controller-system 7.5.0 EXACT)
find_dependency(gz-sim7-tracked-vehicle-system 7.5.0 EXACT)
find_dependency(gz-sim7-trajectory-follower-system 7.5.0 EXACT)
find_dependency(gz-sim7-triggered-publisher-system 7.5.0 EXACT)
find_dependency(gz-sim7-user-commands-system 7.5.0 EXACT)
find_dependency(gz-sim7-velocity-control-system 7.5.0 EXACT)
find_dependency(gz-sim7-wheel-slip-system 7.5.0 EXACT)
find_dependency(gz-sim7-wind-effects-system 7.5.0 EXACT)
find_dependency(gz-sim7-gz 7.5.0 EXACT)

if(NOT TARGET gz-sim7::gz-sim7-all)
  include("${CMAKE_CURRENT_LIST_DIR}/gz-sim7-all-targets.cmake")

  add_library(gz-sim7::all INTERFACE IMPORTED)
  set_target_properties(gz-sim7::all PROPERTIES
    INTERFACE_LINK_LIBRARIES "gz-sim7::gz-sim7-all")

endif()

# Create the "requested" target if it does not already exist
if(NOT TARGET gz-sim7::requested)
  add_library(gz-sim7::requested INTERFACE IMPORTED)
endif()

# Link the "all" target to the "requested" target
get_target_property(gz_requested_components gz-sim7::requested INTERFACE_LINK_LIBRARIES)
if(NOT gz_requested_components)
  set_target_properties(gz-sim7::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "gz-sim7::gz-sim7-all")
else()
  set_target_properties(gz-sim7::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "${gz_requested_components};gz-sim7::gz-sim7-all")
endif()

set(gz-sim7_ALL_LIBRARIES gz-sim7::gz-sim7-all)
